"use strict";

var _tap = require("tap");

var _ = require("./");

var _snabbdomToHtml = require("snabbdom-to-html");

var _snabbdomToHtml2 = _interopRequireDefault(_snabbdomToHtml);

var _init = require("snabbdom-to-html/init");

var _init2 = _interopRequireDefault(_init);

var _modules = require("snabbdom-to-html/modules");

var _modules2 = _interopRequireDefault(_modules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var toHTMLWithPlugins = (0, _init2.default)([_modules2.default.class, _modules2.default.props, _modules2.default.attributes, _modules2.default.style]); /* eslint-disable flowtype/require-parameter-type, flowtype/require-return-type */

(0, _tap.test)("selector", function (_ref) {
  var similar = _ref.similar,
      end = _ref.end;

  similar((0, _.a)({ selector: ".value" }), { sel: "a.value" });
  end();
});

(0, _tap.test)("inner", function (_ref2) {
  var similar = _ref2.similar,
      end = _ref2.end;

  similar((0, _.a)({ inner: "test" }), { text: "test" });
  end();
});

(0, _tap.test)("aria", function (_ref3) {
  var similar = _ref3.similar,
      end = _ref3.end;

  similar((0, _.a)({ aria: { id: "1" } }), { data: { attrs: { "aria-id": "1" } } });
  end();
});

(0, _tap.test)("data", function (_ref4) {
  var similar = _ref4.similar,
      end = _ref4.end;

  similar((0, _.a)({ data: { id: "1" } }), { data: { attrs: { "data-id": "1" } } });
  end();
});

(0, _tap.test)("full", function (_ref5) {
  var similar = _ref5.similar,
      end = _ref5.end;

  similar((0, _.a)({
    "selector": "#a.b.c",
    "inner": "test",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { x: "x" },
    "attrs": { y: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "key": "key",
    "hook": { insert: function insert() {
        return null;
      } }
  }), {
    sel: "a#a.b.c",
    data: {
      "attrs": {
        "y": "y",
        "x": "x",
        "data-name": "Kurtis",
        "data-id": "1",
        "aria-role": "navigation",
        "data-ds": "ds"
      },
      "props": { title: "x" },
      "style": { border: "1px" },
      "class": {
        active: true,
        ignored: false
      },
      "key": "key"
    },
    children: undefined,
    text: "test",
    elm: undefined,
    key: "key"
  });
  end();
});

(0, _tap.test)("html", function (_ref6) {
  var equal = _ref6.equal,
      end = _ref6.end;

  equal((0, _snabbdomToHtml2.default)((0, _.a)({
    "selector": "#a.b.c",
    "inner": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { x: "x" },
    "attrs": { y: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<a id=\"a\" class=\"b c active\" y=\"y\" x=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" title=\"x\" href=\"/a\" style=\"border: 1px\">test</a>");
  end();
});

(0, _tap.test)("html with plugins", function (_ref7) {
  var equal = _ref7.equal,
      end = _ref7.end;

  equal(toHTMLWithPlugins((0, _.a)({
    "selector": "#a.b.c",
    "inner": "test",
    "key": "key",
    "props": { title: "x" },
    "properties": { href: "/a" },
    "attributes": { x: "x" },
    "attrs": { y: "y" },
    "data": {
      id: "1",
      name: "Kurtis"
    },
    "dataset": { ds: "ds" },
    "style": { border: "1px" },
    "on": { click: function click() {
        return null;
      } },
    "aria": { role: "navigation" },
    "class": {
      active: true,
      ignored: false
    },
    "hook": { insert: function insert() {
        return null;
      } }
  })), "<a id=\"a\" class=\"b c active\" title=\"x\" href=\"/a\" y=\"y\" x=\"x\" data-name=\"Kurtis\" data-id=\"1\" aria-role=\"navigation\" data-ds=\"ds\" style=\"border: 1px\">test</a>");
  end();
});